# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####


""" Copyright 2011 GPL licence applies"""

bl_info = {
    "name": "Pie: Menus",
    "description": "Pie Menus for various functionality",
    "author": "Dan Eicher, Sean Olson",
    "version": (1, 0, 0),
    "blender": (2, 6, 4),
    "location": "View3D - Set Keybindings in File->Userprefs->Input Tab->(Search: \"pie\")",
    "warning": '',  # used for warning icon and text in addons panel
    "wiki_url": "",
    "tracker_url": "",
    "category": "3D View"}

#we need to add the piemenus subdirectory to be searched for imports
import sys, os
sys.path.append(os.path.join(os.path.dirname(__file__), '..', 'piemenus'))

#this is the guts of the script
import pie_menu   
#import the individual menus
import pie_viewMenu
import pie_modeMenu
import pie_selectionMenu
import pie_shadeMenu
import pie_pivotMenu
import pie_strokesMenu
import pie_sculptTextureMenu
import pie_greyBrushes
import pie_redBrushes
import pie_tanBrushes


import bpy
from bpy.props import *

def initSceneProperties(scn):
    bpy.types.Scene.viewBool = BoolProperty(name = "View Menu", description = "A Menu for the numpad views")
    scn['viewBool'] = False
    
    bpy.types.Scene.modeBool = BoolProperty(name = "Mode Menu", description = "A Menu for the various blender modes")
    scn['modeBool'] = False

    bpy.types.Scene.modeBool = BoolProperty(name = "Shading Menu", description = "A Menu for the various shading modes")
    scn['shadeBool'] = False


    
    return
#no need to do this until we get panels in 
initSceneProperties(bpy.context.scene)

#future options will go here
# this the main panel

class piemenus_panel(bpy.types.Panel):
    bl_label = "Pie Menus"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {'DEFAULT_CLOSED'}   
    
    #@classmethod
    #def poll(cls, context):
        #if context.scene.viewBool:
            #print('do stuff')
    '''
    def draw(self, context):
        layout = self.layout
        scn = context.scene
        layout.prop(scn, 'viewBool')
        layout.prop(scn, 'modeBool')
    '''    
        

def register():
    bpy.utils.register_module(__name__)

    pie_modeMenu.register()             #done
    pie_selectionMenu.register()        #done
    pie_viewMenu.register()             #done
    pie_shadeMenu.register()            #done
    pie_pivotMenu.register()            #done
    pie_strokesMenu.register()          #done
    pie_sculptTextureMenu.register()    #done
    pie_greyBrushes.register()
    pie_redBrushes.register()
    pie_tanBrushes.register()

   
def unregister():
    bpy.utils.unregister_module(__name__)
    
    pie_modeMenu.unregister()
    pie_selectionMenu.unregister()
    pie_viewMenu.unregister()
    pie_shadeMenu.unregister()
    pie_pivotMenu.unregister()
    pie_strokesMenu.unregister()
    pie_sculptTextureMenu.unregister()
    pie_greyBrushes.unregister()
    pie_redBrushes.unregister()
    pie_tanBrushes.unregister()

 
if __name__ == "__main__":
    register()
